summaryrefslogtreecommitdiff
path: root/fsck-cache.c
diff options
context:
space:
mode:
Diffstat (limited to 'fsck-cache.c')
-rw-r--r--fsck-cache.c8
1 files changed, 3 insertions, 5 deletions
diff --git a/fsck-cache.c b/fsck-cache.c
index fb0d82f332..e328cec75d 100644
--- a/fsck-cache.c
+++ b/fsck-cache.c
@@ -295,14 +295,12 @@ int main(int argc, char **argv)
continue;
if (!get_sha1(arg, head_sha1)) {
- struct commit *commit = lookup_commit(head_sha1);
- struct object *obj;
+ struct object *obj = lookup_object(head_sha1);
- /* Error is printed by lookup_commit(). */
- if (!commit)
+ /* Error is printed by lookup_object(). */
+ if (!obj)
continue;
- obj = &commit->object;
obj->used = 1;
mark_reachable(obj, REACHABLE);
heads++;